
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.2.14'
version = '1.2.14'
full_version = '1.2.14'
git_revision = 'd3eb75179b4dedfb8428fe04d03c1e4cacb871fa'
release = True

if not release:
    version = full_version
    short_version += ".dev"
